@@ -44,7 +44,7 @@ QNetworkRequest ContactsGroupFetchJob::Private::createRequest(const QUrl& url)
     QStringList headers;
     auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    for (const QByteArray &str : qAsConst(rawHeaderList)) {
+    for (const QByteArray &str : std::as_const(rawHeaderList)) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
 
