@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_DRIVE_APP_H
-#define LIBKGAPI2_DRIVE_APP_H
+#pragma once
 
 #include "types.h"
 #include "object.h"
@@ -55,8 +54,8 @@ class KGAPIDRIVE_EXPORT App: public KGAPI2::Object
         friend class App::Private;
     };
 
-    typedef QSharedPointer<Icon> IconPtr;
-    typedef QList<IconPtr> IconsList;
+    using IconPtr = QSharedPointer<Icon>;
+    using IconsList = QList<IconPtr>;
 
     explicit App();
     explicit App(const App &other);
@@ -91,4 +90,3 @@ class KGAPIDRIVE_EXPORT App: public KGAPI2::Object
 
 } /* namespace KGAPI2 */
 
-#endif // LIBKGAPI2_DRIVE_APP_H
